The Game Jam is On
==================

:date: 2023-10-28 08:15
:author: tundish
:tags: python, balladeer, game jam
:category: Blog
:status: draft
:summary: Some initial thoughts on the first full day of the Jam

I haven't written any code yet
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Theme: The Unknown.

Some ideas (see below)

Watching the Rugby was the right thing to do.

Planning the next 10 days XXxxxxxXX

Priority is CSS layout while I have access to a large screen.

Ideas
~~~~~

We begin in the cab of a van. Player is young. just starting to help in a company of repo men.
iNo phone coverage.

Story will be mostly on rails, with some parse exploration.

Missions/Tasks nee questions/answers ans Ask/Say syntax.

Populate list data for input text.

500 cues of SpeechMark?

Too early to know how to structure scene files, so start with Dialogue in Python modules.
Starting point: Balladeer example 12.
